<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk">
<context>
    <name>EllipseOffsetThrough</name>
    <message>
        <location filename="../EllipseOffsetThrough.ui" line="+17"/>
        <source>Number:</source>
        <translation>Počet:</translation>
    </message>
    <message>
        <location filename="../EllipseOffsetThroughInit.js" line="+2"/>
        <source>Parallel Curve (&amp;through Point)</source>
        <translation>Paralelná elipsa (&amp;s pomocou Bodu)</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw parallel curve to ellipse through point</source>
        <translation>Nakreslite k elipse jej paralelku s pomocou bodu</translation>
    </message>
</context>
</TS>
